# -*- encoding: utf-8 -*-

"""
Figment Visualization
=====================

Figment Visualization is a framework to visualize data using templates.


"""


from importlib.metadata import version as _version


__author__ = "Umesh Mohan <moh@nume.sh>"
__copyright__ = "2021, Umesh Mohan"

__version__ = _version("figvis")



# -*- encoding: utf-8 -*-

from base64 import b64decode
from pathlib import Path

from lxml import etree
from selenium.webdriver import Firefox, FirefoxOptions
from selenium.webdriver.common.print_page_options import PrintOptions


def svg_to_pdf(
    svg_file_path: Path,
    pdf_file_path: Path,
):
    svg_dimensions = dimensions(svg_file_path)
    firefox_options = FirefoxOptions()
    firefox_options.headless = True
    with Firefox(options=firefox_options) as firefox:
        print_options = PrintOptions()
        print_options.margin_top = 0
        print_options.margin_bottom = 0
        print_options.margin_left = 0
        print_options.margin_right = 0
        print_options.scale = 1
        print_options.shrink_to_fit = False
        print_options.page_ranges = ["1"]
        print_options.page_width = svg_dimensions["width"]
        print_options.page_height = svg_dimensions["height"]
        firefox.get(svg_file_path.as_uri())
        pdf_data = b64decode(firefox.print_page(print_options=print_options))
    with open(pdf_file_path, "wb") as output_file:
        output_file.write(pdf_data)


def dimensions(svg_file_path: Path):
    svg = etree.parse(str(svg_file_path)).getroot()
    return {
        "width": to_cm(svg.get("width")),
        "height": to_cm(svg.get("height"))
    }


def to_cm(quantity: str) -> float:
    unit = quantity[-2:].lower()
    value = float(quantity[:-2])
    if unit == "cm":
        value_cm = value
    elif unit == "mm":
        value_cm = value / 10
    elif unit == "in":
        value_cm = value * 2.54
    elif unit == "pt":
        value_cm = (value / 72) * 2.54
    elif unit == "pc":
        value_cm = ((value * 12) / 72) * 2.54
    return value_cm



#! /usr/bin/env python3
# -*- encoding: utf-8 -*-


from pathlib import Path

import typer

from figvis.svg_to_pdf import svg_to_pdf as svg_to_pdf_

app = typer.Typer(help="Figment Visualization")


@app.command()
def svg_to_pdf(
    svg_file_path: Path = typer.Argument(..., help="Input SVG file"),
    pdf_file_path: Path = typer.Argument(..., help="Output PDF file"),
):
    svg_to_pdf_(svg_file_path.resolve(), pdf_file_path.resolve())


if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['figvis', 'figvis.cli']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.0.1,<4.0.0',
 'lxml>=4.6.3,<5.0.0',
 'selenium>=4.0.0.b4',
 'typer>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['figvis = figvis.cli.main:app']}

setup_kwargs = {
    'name': 'figvis',
    'version': '0.1.0a10',
    'description': 'Figment Visualization is a framework to visualize data using templates',
    'long_description': 'figvis\n======\n\nFigment Visualization is a framework to visualize data using templates\n\nRequirements\n++++++++++++\n\nInstallation\n++++++++++++\n\nUsage\n+++++\n\nCommand line\n------------\n\nProgrammatic\n------------\n\nExample\n-------',
    'author': 'Umesh Mohan',
    'author_email': 'moh@nume.sh',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://u-m.gitlab.io/figvis/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
